<?php
/**
 * Implements styles set in the theme customizer
 *
 * @package Customizer Library Avant
 */

if ( ! function_exists( 'customizer_library_avant_build_styles' ) && class_exists( 'Customizer_Library_Styles' ) ) :
/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * @since  1.0.0.
 *
 * @return void
 */
function customizer_library_avant_build_styles() {
	
	// Site Container Set Width
	$setting = 'avant-set-container-width';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$container_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-container,
				.content-boxed,
				.site-boxed,
				.site-boxed .stick-header.stuck'
			),
			'declarations' => array(
				'max-width' => $container_width . 'px'
			)
		) );
	}
	
	// Set Sidebar Width
	$setting = 'avant-set-sidebar-width';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$sidebar_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce #container,
				.woocommerce-page #container,
				.content-area'
			),
			'declarations' => array(
				'width' => ( 95 - $sidebar_width ) . '%'
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce .content-boxed #container,
				.woocommerce-page .content-boxed #container,
				.content-boxed .content-area'
			),
			'declarations' => array(
				'width' => ( 100 - $sidebar_width ) . '%'
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.widget-area'
			),
			'declarations' => array(
				'width' => $sidebar_width . '%'
			)
		) );
	}
	
	// Primary Color
	$setting = 'avant-primary-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-top-border,
				#comments .form-submit #submit,
				.search-block .search-submit,
				.side-aligned-social a.social-icon,
				.no-results-btn,
				button,
				input[type="button"],
				input[type="reset"],
				input[type="submit"],
				.widget-title-style-underline-short .widget-area .widget-title:after,
				.woocommerce ul.products li.product a.add_to_cart_button, .woocommerce-page ul.products li.product a.add_to_cart_button,
				.woocommerce ul.products li.product .onsale, .woocommerce-page ul.products li.product .onsale,
				.woocommerce button.button.alt,
				.woocommerce-page button.button.alt,
				.woocommerce input.button.alt:hover,
				.woocommerce-page #content input.button.alt:hover,
				.woocommerce .cart-collaterals .shipping_calculator .button,
				.woocommerce-page .cart-collaterals .shipping_calculator .button,
				.woocommerce a.button,
				.woocommerce-page a.button,
				.woocommerce input.button,
				.woocommerce-page #content input.button,
				.woocommerce-page input.button,
				.woocommerce #review_form #respond .form-submit input,
				.woocommerce-page #review_form #respond .form-submit input,
				.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover,
				.woocommerce button.button.alt.disabled,.woocommerce button.button.alt.disabled:hover,
				.single-product span.onsale,
				.main-navigation ul ul a:hover,
				.main-navigation ul ul li.current-menu-item > a,
				.main-navigation ul ul li.current_page_item > a,
				.main-navigation ul ul li.current-menu-parent > a,
				.main-navigation ul ul li.current_page_parent > a,
				.main-navigation ul ul li.current-menu-ancestor > a,
				.main-navigation ul ul li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-solid .current_page_item > a,
				.woocommerce .widget_price_filter .ui-slider .ui-slider-range,
				.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
				.wpcf7-submit,
				.wp-paginate li a:hover,
				.wp-paginate li a:active,
				.wp-paginate li .current,
				.wp-paginate.wpp-modern-grey li a:hover,
				.wp-paginate.wpp-modern-grey li .current'
			),
			'declarations' => array(
				'background' => 'inherit',
                'background-color' => $color
			)
		) );
	}
	
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'a,
				.content-area .entry-content a,
				#comments a,
				.post-edit-link,
				.site-title a,
				.error-404.not-found .page-header .page-title span,
				.search-button .fa-search,
				.header-cart-checkout.cart-has-items .fa-shopping-cart,
				.woocommerce ul.products li.product .price,
				.site-header-top-right .social-icon:hover,
				.site-footer-bottom-bar .social-icon:hover,
				.site-footer-bottom-bar ul li a:hover,
				a.privacy-policy-link:hover,
				.main-navigation.avant-nav-style-plain ul > li > a:hover,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-item > a,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-ancestor > a,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-parent > a,
				.main-navigation.avant-nav-style-plain ul > li.current_page_parent > a,
				.main-navigation.avant-nav-style-plain ul > li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-plain .current_page_item > a'
			),
			'declarations' => array(
                'color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation.avant-nav-style-underlined ul > li > a:hover,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-item > a,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-ancestor > a,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-parent > a,
				.main-navigation.avant-nav-style-underlined ul > li.current_page_parent > a,
				.main-navigation.avant-nav-style-underlined ul > li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-underlined .current_page_item > a'
			),
			'declarations' => array(
                'box-shadow' => '0 -4px 0 ' . $color . ' inset'
			)
		) );
	}
	
	

	// Secondary Color
	$setting = 'avant-secondary-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation button:hover,
				#comments .form-submit #submit:hover,
				.search-block .search-submit:hover,
				.no-results-btn:hover,
				button,
				input[type="button"],
				input[type="reset"],
				input[type="submit"],
				.woocommerce input.button.alt,
				.woocommerce-page #content input.button.alt,
				.woocommerce .cart-collaterals .shipping_calculator .button,
				.woocommerce-page .cart-collaterals .shipping_calculator .button,
				.woocommerce a.button:hover,
				.woocommerce-page a.button:hover,
				.woocommerce input.button:hover,
				.woocommerce-page #content input.button:hover,
				.woocommerce-page input.button:hover,
				.woocommerce ul.products li.product a.add_to_cart_button:hover,
				.woocommerce-page ul.products li.product a.add_to_cart_button:hover,
				.woocommerce button.button.alt:hover,
				.woocommerce-page button.button.alt:hover,
				.woocommerce #review_form #respond .form-submit input:hover,
				.woocommerce-page #review_form #respond .form-submit input:hover,
				.woocommerce-cart .wc-proceed-to-checkout a.checkout-button,
				.woocommerce .widget_price_filter .price_slider_wrapper .ui-widget-content,
				.wpcf7-submit:hover'
			),
			'declarations' => array(
				'background' => 'inherit',
                'background-color' => $color
			)
		) );
	}
	
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'a:hover,
				.avant-header-nav ul li a:hover,
				.content-area .entry-content a:hover,
				.header-social .social-icon:hover,
				.widget-area .widget a:hover,
				.site-footer-widgets .widget a:hover,
				.site-footer .widget a:hover,
				.search-btn:hover,
				.search-button .fa-search:hover,
				.woocommerce #content div.product p.price,
				.woocommerce-page #content div.product p.price,
				.woocommerce-page div.product p.price,
				.woocommerce #content div.product span.price,
				.woocommerce div.product span.price,
				.woocommerce-page #content div.product span.price,
				.woocommerce-page div.product span.price,
				.woocommerce ul.products li.product .price:hover,
				.woocommerce #content div.product .woocommerce-tabs ul.tabs li.active,
				.woocommerce div.product .woocommerce-tabs ul.tabs li.active,
				.woocommerce-page #content div.product .woocommerce-tabs ul.tabs li.active,
				.woocommerce-page div.product .woocommerce-tabs ul.tabs li.active'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	
	// Site Boxed Background Color
	$setting = 'avant-boxed-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.content-boxed'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	
	// Body Font
	$setting = 'avant-body-font';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'body,
				.widget-area .widget a'
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );

	}
	
	// Site Title & Tagline Color
	$setting = 'avant-site-title-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-title a'
			),
			'declarations' => array(
				'color' => $color . ' !important'
			)
		) );
	}
	$setting = 'avant-site-tagline-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-description'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Body Font Color
	$setting = 'avant-body-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'body,
                .widget-area .widget a,
                .woocommerce .woocommerce-breadcrumb a,
                .woocommerce .woocommerce-breadcrumb,
                .woocommerce-page .woocommerce-breadcrumb,
                .woocommerce #content ul.products li.product span.price,
                .woocommerce-page #content ul.products li.product span.price,
                .woocommerce div.product .woocommerce-tabs ul.tabs li a'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}

	// Heading Font
	$setting = 'avant-heading-font';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'h1, h2, h3, h4, h5, h6,
                h1 a, h2 a, h3 a, h4 a, h5 a, h6 a,
                .widget-area .widget-title,
                .main-navigation ul li a,
                .woocommerce table.cart th,
                .woocommerce-page #content table.cart th,
                .woocommerce-page table.cart th,
                .woocommerce input.button.alt,
                .woocommerce-page #content input.button.alt,
                .woocommerce table.cart input,
                .woocommerce-page #content table.cart input,
                .woocommerce-page table.cart input,
                button, input[type="button"],
                input[type="reset"],
                input[type="submit"]',
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );

	}
	
	// Heading Font Color
	$setting = 'avant-heading-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'h1, h2, h3, h4, h5, h6,
                h1 a, h2 a, h3 a, h4 a, h5 a, h6 a,
                .widget-area .widget-title'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	
	// Site Title Font
	$setting = 'avant-title-font';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-title a'
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );

	}
	// Site Title Font Size
	$setting = 'avant-title-font-size';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_font_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-title'
			),
			'declarations' => array(
				'font-size' => $title_font_size . 'px'
			)
		) );
	}
	$setting = 'avant-site-tagline-case-normal';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-description'
			),
			'declarations' => array(
				'text-transform' => 'none'
			)
		) );

	}
	// Site Tagline Font
	$setting = 'avant-tagline-font';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-description'
			),
			'declarations' => array(
				'font-family' => $stack
			)
		) );

	}
	// Site Title Font Size
	$setting = 'avant-tagline-font-size';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_font_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-description'
			),
			'declarations' => array(
				'font-size' => $title_font_size . 'px'
			)
		) );
	}
	// Site Title Bottom Margin
	$setting = 'avant-title-bottom-margin';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_bottom_margin = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-title'
			),
			'declarations' => array(
				'margin-bottom' => $title_bottom_margin . 'px'
			)
		) );
	}
	
	// Site Logo Max Width
	$setting = 'avant-logo-max-width';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$logo_max_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-branding a.custom-logo-link'
			),
			'declarations' => array(
				'max-width' => $logo_max_width . 'px'
			)
		) );
	}
	
	// Site Logo Top Padding
	$setting = 'avant-branding-top-pad';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$logo_top_pad = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-branding'
			),
			'declarations' => array(
				'padding-top' => $logo_top_pad . 'px'
			)
		) );
	}
	// Site Logo Bottom Padding
	$setting = 'avant-branding-bottom-pad';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$logo_bottom_pad = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-branding'
			),
			'declarations' => array(
				'padding-bottom' => $logo_bottom_pad . 'px'
			)
		) );
	}
	// Site Logo Bottom Padding
	$setting = 'avant-logo-top-pad';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$logo_bottom_pad = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-branding-block'
			),
			'declarations' => array(
				'padding-top' => $logo_bottom_pad . 'px'
			)
		) );
	}
	$setting = 'avant-header-nav-case-normal';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$stack = customizer_library_get_font_stack( $mod );

	if ( $mod != customizer_library_get_default( $setting ) ) {

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation li'
			),
			'declarations' => array(
				'text-transform' => 'none'
			)
		) );

	}
	// Sidebar Widget Title Size
	$setting = 'avant-blog-widget-title-size';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$widget_title_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.widget-area .widget-title'
			),
			'declarations' => array(
				'font-size' => $widget_title_size . 'px'
			)
		) );
	}
	
	// Site Logo Max Width
	$setting = 'avant-blog-blocks-spacing';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$blog_blocks_space = esc_attr( $mod );
		
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.blog-blocks-wrap-inner'
			),
			'declarations' => array(
				'margin' => '0 -' . $blog_blocks_space . 'px'
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.blog-blocks-wrap .blog-blocks-layout,
				.blog-break-blocks .blog-blocks-wrap article.blog-blocks-layout'
			),
			'declarations' => array(
				'margin' => '0 0 ' . ($blog_blocks_space * 2) . 'px'
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.blog-style-postblock .blog-post-blocks-inner,
				.blog-style-imgblock .blog-post-blocks-inner'
			),
			'declarations' => array(
				'margin' => '0 ' . $blog_blocks_space . 'px 1px'
			)
		) );
	}
	
	// Header Background Color
	$setting = 'avant-header-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-top-bar.site-header-layout-one .search-block,
				.site-header.site-header-layout-one .site-header-top,
				.site-header.site-header-layout-one .search-block,
				.site-header.site-header-layout-one .main-navigation ul ul,
				.site-header.site-header-layout-two,
				.site-header.site-header-layout-two .site-header-top,
				.site-header.site-header-layout-two .main-navigation ul ul,
				.site-header.site-header-layout-four,
				.site-header.site-header-layout-four .main-navigation ul ul,
				.site-header.site-header-layout-four .stick-header.stuck,
				.site-header.site-header-layout-five,
				.site-header.site-header-layout-five .main-navigation ul ul,
				.site-header.site-header-layout-five .stick-header.stuck,
				.site-header.site-header-layout-three,
				.site-header.site-header-layout-three .site-header-top,
				.site-header.site-header-layout-three .main-navigation ul ul,
				.site-header-side-container-inner,
				.site-top-bar.site-header-layout-six,
				.site-header.site-header-layout-six,
				.site-header.site-header-layout-six .main-navigation ul ul,
				.site-header-side-container .search-block'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	// Transparent Header Background Color
	$setting = 'avant-header-bg-color';
	$setting_opacity = 'avant-header-bg-opacity';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$mod_opacity = get_theme_mod( $setting_opacity, customizer_library_get_default( $setting_opacity ) );

	if ( $mod !== customizer_library_get_default( $setting ) || $mod_opacity !== customizer_library_get_default( $setting_opacity ) ) {

		$color = sanitize_hex_color( $mod );
		$rgba_color = customizer_library_hex_to_rgb( $color );
		$opacity = esc_attr( $mod_opacity );
		
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-seven,
				.site-header.site-header-layout-seven .main-navigation ul ul,
				.site-header.site-header-layout-seven .stick-header.stuck'
			),
			'declarations' => array(
				'background-color' => 'rgba(' . $rgba_color['r'] . ', ' . $rgba_color['g'] . ', ' . $rgba_color['b'] . ', 0.' . $opacity . ');'
			)
		) );
	}
	// Header Font Color
	$setting = 'avant-header-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header-top,
				.site-header-social,
				.site-header-search,
				.site-header-layout-one .header-cart,
				.site-header-layout-six .header-cart,
				.main-navigation ul li a,
				.site-header-top .social-icon,
				.site-header.site-header-layout-six .site-top-bar-right-extra-txt'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	// Top Bar Background Color
	$setting = 'avant-topbar-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-top-bar.site-header-layout-one,
				.site-top-bar.site-header-layout-one .site-top-bar-left,
				.site-top-bar.site-header-layout-one .site-top-bar-right,
				.site-top-bar.site-header-layout-one .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-two,
				.site-top-bar.site-header-layout-two .site-top-bar-left,
				.site-top-bar.site-header-layout-two .site-top-bar-right,
				.site-top-bar.site-header-layout-two .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-two .search-block,
				.site-top-bar.site-header-layout-three,
				.site-top-bar.site-header-layout-three .site-top-bar-left,
				.site-top-bar.site-header-layout-three .site-top-bar-right,
				.site-top-bar.site-header-layout-three .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-three .search-block,
				.site-top-bar.site-header-layout-four,
				.site-top-bar.site-header-layout-four .site-top-bar-left,
				.site-top-bar.site-header-layout-four .site-top-bar-right,
				.site-top-bar.site-header-layout-four .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-four .search-block,
				.site-top-bar.site-header-layout-five,
				.site-top-bar.site-header-layout-five .site-top-bar-left,
				.site-top-bar.site-header-layout-five .site-top-bar-right,
				.site-top-bar.site-header-layout-five .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-five .search-block,
				.site-top-bar.site-header-layout-six,
				.site-top-bar.site-header-layout-six .avant-header-nav ul ul,
				.site-top-bar.site-header-layout-seven,
				.site-top-bar.site-header-layout-seven .site-top-bar-left,
				.site-top-bar.site-header-layout-seven .site-top-bar-right,
				.site-top-bar.site-header-layout-seven .search-block
				'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	// Top Bar Font Color
	$setting = 'avant-topbar-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-top-bar'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	// Header Cart Colors
	$setting = 'avant-header-cart-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.header-cart .site-header-cart'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	$setting = 'avant-header-cart-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.header-cart .site-header-cart,
				.header-cart .site-header-cart ul.cart_list li a,
				.header-cart .site-header-cart ul.product_list_widget li a,
				.header-cart .site-header-cart .widget_shopping_cart .total'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	
	// Header 2 & 4 Nav Colors
	$setting = 'avant-navi-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-two .site-header-top,
				.site-header.site-header-layout-two .main-navigation ul ul,
				.site-header.site-header-layout-three .site-header-top,
				.site-header.site-header-layout-three .main-navigation ul ul,
				.site-header.site-header-layout-six .site-header-top,
				.site-header.site-header-layout-six .main-navigation ul ul'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	$setting = 'avant-navi-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-two .site-header-top,
				.site-header.site-header-layout-two .main-navigation ul li a,
				.site-header.site-header-layout-three .site-header-top,
				.site-header.site-header-layout-three .main-navigation ul li a,
				.site-header.site-header-layout-six .site-header-top,
				.site-header.site-header-layout-six .main-navigation ul li a,
				.site-header-layout-six .header-cart'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	// Navigation Drop Down Background Color
	$setting = 'avant-nav-drop-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-one .main-navigation ul ul,
				.site-header.site-header-layout-two .main-navigation ul ul,
				.site-header.site-header-layout-three .main-navigation ul ul,
				.site-header.site-header-layout-four .main-navigation ul ul,
				.site-header.site-header-layout-five .main-navigation ul ul,
				.site-header.site-header-layout-six .main-navigation ul ul'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	// Transparent Header Background Color
	$setting = 'avant-nav-drop-bg-color';
	$setting_opacity = 'avant-nav-drop-opacity';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );
	$mod_opacity = get_theme_mod( $setting_opacity, customizer_library_get_default( $setting_opacity ) );

	if ( $mod !== customizer_library_get_default( $setting ) || $mod_opacity !== customizer_library_get_default( $setting_opacity ) ) {

		$color = sanitize_hex_color( $mod );
		$rgba_color = customizer_library_hex_to_rgb( $color );
		$opacity = esc_attr( $mod_opacity );
		
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-seven .main-navigation ul ul'
			),
			'declarations' => array(
				'background-color' => 'rgba(' . $rgba_color['r'] . ', ' . $rgba_color['g'] . ', ' . $rgba_color['b'] . ', 0.' . $opacity . ');'
			)
		) );
	}
	// Navigation Drop Down Font Color
	$setting = 'avant-nav-drop-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header.site-header-layout-one .main-navigation ul ul li a,
				.site-header.site-header-layout-two .main-navigation ul ul li a,
				.site-header.site-header-layout-three .main-navigation ul ul li a,
				.site-header.site-header-layout-four .main-navigation ul ul li a,
				.site-header.site-header-layout-five .main-navigation ul ul li a,
				.site-header.site-header-layout-six .main-navigation ul ul li a,
				.site-header.site-header-layout-seven .main-navigation ul ul li a'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	// Navigation Active Color
	$setting = 'avant-navi-selected-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation.avant-nav-style-solid ul > li > a:hover,
				.main-navigation.avant-nav-style-solid ul > li.current-menu-item > a,
				.main-navigation.avant-nav-style-solid ul > li.current-menu-ancestor > a,
				.main-navigation.avant-nav-style-solid ul > li.current-menu-parent > a,
				.main-navigation.avant-nav-style-solid ul > li.current_page_parent > a,
				.main-navigation.avant-nav-style-solid ul > li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-solid .current_page_item > a,
				.main-navigation ul ul a:hover,
				.main-navigation ul ul li.current-menu-item > a,
				.main-navigation ul ul li.current_page_item > a,
				.main-navigation ul ul li.current-menu-parent > a,
				.main-navigation ul ul li.current_page_parent > a,
				.main-navigation ul ul li.current-menu-ancestor > a,
				.main-navigation ul ul li.current_page_ancestor > a'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.header-cart-checkout.cart-has-items .fa-shopping-cart,
				.main-navigation.avant-nav-style-plain ul > li > a:hover,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-item > a,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-ancestor > a,
				.main-navigation.avant-nav-style-plain ul > li.current-menu-parent > a,
				.main-navigation.avant-nav-style-plain ul > li.current_page_parent > a,
				.main-navigation.avant-nav-style-plain ul > li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-plain .current_page_item > a'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation.avant-nav-style-underlined ul > li > a:hover,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-item > a,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-ancestor > a,
				.main-navigation.avant-nav-style-underlined ul > li.current-menu-parent > a,
				.main-navigation.avant-nav-style-underlined ul > li.current_page_parent > a,
				.main-navigation.avant-nav-style-underlined ul > li.current_page_ancestor > a,
				.main-navigation.avant-nav-style-underlined .current_page_item > a'
			),
			'declarations' => array(
				'box-shadow' => '0 -4px 0 ' . $color . ' inset'
			)
		) );
	}
	// Mobile Navigation Colors
	$setting = 'avant-mobile-nav-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'#main-menu'
			),
			'declarations' => array(
				'background-color' => $color
			),
			'media' => '(max-width: 980px)'
		) );
	}
	$setting = 'avant-mobile-nav-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation li a,
				a.header-cart-contents'
			),
			'declarations' => array(
				'color' => $color . ' !important'
			),
			'media' => '(max-width: 980px)'
		) );
	}
	$setting = 'avant-mobile-nav-font-hover-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation ul li a:hover'
			),
			'declarations' => array(
				'color' => $color . ' !important'
			),
			'media' => '(max-width: 980px)'
		) );
	}
	$setting = 'avant-mobile-nav-ddbtn-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.menu-dropdown-btn'
			),
			'declarations' => array(
				'background-color' => $color
			),
			'media' => '(max-width: 980px)'
		) );
	}
	$setting = 'avant-mobile-nav-ddbg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.main-navigation ul ul'
			),
			'declarations' => array(
				'background-color' => $color . ' !important'
			),
			'media' => '(max-width: 980px)'
		) );
	}
	
	// Footer Background Color
	$setting = 'avant-footer-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-standard,
				.site-footer.site-footer-social,
				.site-footer.site-footer-custom'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	// Footer Font Color
	$setting = 'avant-footer-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	// Footer Heading Font Color
	$setting = 'avant-footer-heading-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer .widgettitle,
				.site-footer .widget-title'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer .widgettitle,
				.site-footer .widget-title'
			),
			'declarations' => array(
				'border-bottom' => '1px dotted ' . $color
			)
		) );
	}
	// Footer Bottom Bar Background Color
	$setting = 'avant-footer-bottombar-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-bottom-bar'
			),
			'declarations' => array(
				'background-color' => $color
			)
		) );
	}
	// Footer Bottom Bar Font Color
	$setting = 'avant-footer-bottombar-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-bottom-bar'
			),
			'declarations' => array(
				'color' => $color
			)
		) );
	}
	
	// Pages Background Color
	$setting = 'avant-content-bg-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$page_bg_color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce #container,
				.woocommerce-page #container,
				.content-area,
				.widget-area,
				.blog-break-blocks article.hentry,
				.widget-area.sidebar-break-blocks .widget,
				.blog-break-blocks .blog-blocks-wrap article.blog-blocks-layout .blog-blocks-content,
				.blog-break-blocks .blog-post-blocks-inner.blog-post-shape-round'
			),
			'declarations' => array(
				'background-color' => $page_bg_color
			)
		) );
	}
	
	// Page Title Color
	$setting = 'avant-page-title-font-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-main > .entry-header h2,
				.woocommerce-products-header h1,
				.single .entry-title'
			),
			'declarations' => array(
				'color' => $title_color
			)
		) );
	}
	// Blog List Title Color
	$setting = 'avant-bloglist-title-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.post-loop-content .entry-title a,
				.blog-style-postblock .blog-post-blocks-inner h3 a,
				.blog-style-imgblock .blog-blocks-content-inner h3,
				.blog-style-imgblock .blog-blocks-content-inner .entry-meta'
			),
			'declarations' => array(
				'color' => $title_color
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.blog-style-imgblock .blog-blocks-content-inner'
			),
			'declarations' => array(
				'border-color' => $title_color
			)
		) );
	}
	// Sidebar Widget Title Color
	$setting = 'avant-sidebar-widget-title-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.widget-area .widget-title'
			),
			'declarations' => array(
				'color' => $title_color
			)
		) );
	}
	// WooCommerce Title Size
	$setting = 'avant-wc-product-title-size';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce ul.products li.product h3,
				.woocommerce-page ul.products li.product h3,
				.woocommerce ul.products li.product .woocommerce-loop-category__title,
				.woocommerce ul.products li.product .woocommerce-loop-product__title'
			),
			'declarations' => array(
				'font-size' => $title_size . 'px'
			)
		) );
	}
	// WooCommerce Title Color
	$setting = 'avant-wc-product-title-color';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_color = sanitize_hex_color( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce ul.products li.product h3,
				.woocommerce-page ul.products li.product h3,
				.woocommerce ul.products li.product .woocommerce-loop-category__title,
				.woocommerce ul.products li.product .woocommerce-loop-product__title'
			),
			'declarations' => array(
				'color' => $title_color
			)
		) );
	}
	
	// Footer Padding Settings
	$setting = 'avant-footer-top-pad';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$footer_top_pad = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-standard .site-footer-widgets,
				.site-footer-social .site-footer-icons,
				.site-footer-custom .site-footer-widgets'
			),
			'declarations' => array(
				'padding-top' => $footer_top_pad . 'px'
			)
		) );
	}
	$setting = 'avant-footer-bottom-pad';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$footer_top_pad = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-standard .site-footer-widgets,
				.site-footer-social .site-footer-icons,
				.site-footer-custom .site-footer-widgets'
			),
			'declarations' => array(
				'padding-bottom' => $footer_top_pad . 'px'
			)
		) );
	}
	
	// Footer Custom custom widths
	if ( get_theme_mod( 'avant-footer-customize' ) ) :
		
		// Site Footer Column Widths
		$setting = 'avant-footer-customize-col-1';
		$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

		if ( $mod !== customizer_library_get_default( $setting ) ) {

			$footer_col_one = esc_attr( $mod );

			Customizer_Library_Styles()->add( array(
				'selectors' => array(
					'.footer-custom-block.footer-custom-one'
				),
				'declarations' => array(
					'width' => $footer_col_one . '%'
				)
			) );
		}
		$setting = 'avant-footer-customize-col-2';
		$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

		if ( $mod !== customizer_library_get_default( $setting ) ) {

			$footer_col_two = esc_attr( $mod );

			Customizer_Library_Styles()->add( array(
				'selectors' => array(
					'.footer-custom-block.footer-custom-two'
				),
				'declarations' => array(
					'width' => $footer_col_two . '%'
				)
			) );
		}
		$setting = 'avant-footer-customize-col-3';
		$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

		if ( $mod !== customizer_library_get_default( $setting ) ) {

			$footer_col_three = esc_attr( $mod );

			Customizer_Library_Styles()->add( array(
				'selectors' => array(
					'.footer-custom-block.footer-custom-three'
				),
				'declarations' => array(
					'width' => $footer_col_three . '%'
				)
			) );
		}
		$setting = 'avant-footer-customize-col-4';
		$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

		if ( $mod !== customizer_library_get_default( $setting ) ) {

			$footer_col_four = esc_attr( $mod );

			Customizer_Library_Styles()->add( array(
				'selectors' => array(
					'.footer-custom-block.footer-custom-four'
				),
				'declarations' => array(
					'width' => $footer_col_four . '%'
				)
			) );
		}
		$setting = 'avant-footer-customize-col-5';
		$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

		if ( $mod !== customizer_library_get_default( $setting ) ) {

			$footer_col_five = esc_attr( $mod );

			Customizer_Library_Styles()->add( array(
				'selectors' => array(
					'.footer-custom-block.footer-custom-five'
				),
				'declarations' => array(
					'width' => $footer_col_five . '%'
				)
			) );
		}
	
	endif;

	// Remove WC Categories Count
	$setting = 'avant-remove-cats-count';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$widget_title_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'ul.products mark.count'
			),
			'declarations' => array(
				'display' => 'none'
			)
		) );
	}
	// Footer Icon Sizing
	$setting = 'avant-footer-social-icon-size';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$footer_icon_size = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-footer-social .footer-social-icon'
			),
			'declarations' => array(
				'font-size' => $footer_icon_size . 'px'
			)
		) );
	}
	// Widget Spacing
	$setting = 'avant-page-widget-spacing';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$widget_spacing = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.widget-area .widget'
			),
			'declarations' => array(
				'margin' => '0 0 ' . $widget_spacing . 'px'
			)
		) );
	}
	// Content Border Radius
	$setting = 'avant-page-content-spacing';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$content_bradius = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce .avant-site-full-width #container,
				.avant-site-full-width .content-area,
				.avant-site-full-width .widget-area,
				.avant-site-full-width .widget-area.sidebar-break-blocks .widget,
				.blog-break-blocks article.hentry,
				.blog-break-blocks .site-main > .entry-header,
				.blog-style-imgblock .blog-post-blocks-inner,
				.blog-style-postblock .blog-post-blocks-inner'
			),
			'declarations' => array(
				'border-radius' => $content_bradius . 'px',
				'overflow' => 'hidden'
			)
		) );
	}
	$setting = 'avant-wc-mobile-prod-full-width';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$title_bottom_margin = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce ul.products,
    			.woocommerce-page ul.products'
			),
			'declarations' => array(
				'margin' => '0 0 10px !important'
			),
			'media' => '(max-width: 580px)'
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce ul.products li.product,
    			.woocommerce-page ul.products li.product'
			),
			'declarations' => array(
				'width' => '100% !important',
				'margin' => '0 0 24px !important'
			),
			'media' => '(max-width: 580px)'
		) );
	}
	$setting = 'avant-site-title-uc';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$container_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-title'
			),
			'declarations' => array(
				'text-transform' => 'uppercase'
			)
		) );
	}
	$setting = 'avant-header-sticky-nav-onmobile';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$container_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header-layout-one .stick-header.stuck,
				.site-header-layout-two .stick-header.stuck,
				.site-header-layout-three .stick-header.stuck,
				.site-header-layout-four .stick-header.stuck,
				.site-header-layout-five .stick-header.stuck,
				.site-header-layout-seven .stick-header.stuck'
			),
			'declarations' => array(
				'position' => 'relative !important',
				'top' => '0 !important',
				'left' => '0 !important',
				'width' => 'auto !important'
			),
			'media' => '(max-width: 782px)'
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.site-header-layout-six .stick-header.stuck'
			),
			'declarations' => array(
				'position' => 'relative !important',
				'top' => '0 !important',
				'left' => '0 !important',
				'width' => 'auto !important'
			),
			'media' => '(max-width: 980px)'
		) );
	}
	$setting = 'avant-slider-mobile-set-height';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$container_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.home-slider-block'
			),
			'declarations' => array(
				'height' => '260px'
			),
			'media' => '(max-width: 700px)'
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.home-slider-block img'
			),
			'declarations' => array(
				'width' => '100%',
				'height' => '100%'
			),
			'media' => '(max-width: 700px)'
		) );
	}
	$setting = 'avant-slider-mobile-remove-txt';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$container_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.home-slider-block-inner'
			),
			'declarations' => array(
				'display' => 'none !important'
			),
			'media' => '(max-width: 700px)'
		) );
	}
	// Set WC Product Page Col Widths
	$setting = 'avant-set-wc-single-col-width';
	$mod = get_theme_mod( $setting, customizer_library_get_default( $setting ) );

	if ( $mod !== customizer_library_get_default( $setting ) ) {

		$wc_col_width = esc_attr( $mod );

		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce div.product div.summary'
			),
			'declarations' => array(
				'width' => ( 96 - $wc_col_width ) . '%'
			)
		) );
		Customizer_Library_Styles()->add( array(
			'selectors' => array(
				'.woocommerce div.product div.images'
			),
			'declarations' => array(
				'width' => $wc_col_width . '%'
			)
		) );
	}

}
endif;

add_action( 'customizer_library_styles', 'customizer_library_avant_build_styles' );

if ( ! function_exists( 'customizer_library_avant_styles' ) ) :
/**
 * Generates the style tag and CSS needed for the theme options.
 *
 * By using the "Customizer_Library_Styles" filter, different components can print CSS in the header.
 * It is organized this way to ensure there is only one "style" tag.
 *
 * @since  1.0.0.
 *
 * @return void
 */
function customizer_library_avant_styles() {

	do_action( 'customizer_library_styles' );

	// Echo the rules
	$css = Customizer_Library_Styles()->build();

	if ( ! empty( $css ) ) {
		echo "\n<!-- Begin Custom CSS -->\n<style type=\"text/css\" id=\"avant-custom-css\">\n";
		echo $css;
		echo "\n</style>\n<!-- End Custom CSS -->\n";
	}
}
endif;

add_action( 'wp_head', 'customizer_library_avant_styles', 11 );